PipelineIo
==========

.. currentmodule:: toasty.pipeline

.. autoclass:: PipelineIo
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PipelineIo.check_exists
      ~PipelineIo.get_item
      ~PipelineIo.list_items
      ~PipelineIo.load_from_config
      ~PipelineIo.put_item
      ~PipelineIo.save_config

   .. rubric:: Methods Documentation

   .. automethod:: check_exists
   .. automethod:: get_item
   .. automethod:: list_items
   .. automethod:: load_from_config
   .. automethod:: put_item
   .. automethod:: save_config
